kimono
======

USAGE


.. code:: python

    from kimono import Kimono
    api = Kimono('APIKEY', 'APIID')

IMPLEMENTED


`Retrieve an API <https://www.kimonolabs.com/apidocs#RetrieveApi>`__

.. code:: python

    api.retrieve_api()

`List all APIs <https://www.kimonolabs.com/apidocs#ListApis>`__

.. code:: python

    api.list_apis()
